function varargout = exchange1(Sys,Exp,Opt)

% Wrapper for exchange function
% Working with natural isotope mixtures

if (nargin<2), Exp = struct; end
if (nargin<3), Opt = struct; end
if ~isstruct(Sys), error('Spin system structure Sys is missing.'); end
if ~isstruct(Exp), error('Experiment structure Exp is missing.'); end
% Experimental parameters
%------------------------------------------------------------
if ~isfield(Exp,'mwFreq'), Exp.mwFreq = 9.5; end
if ~isfield(Exp,'nPoints'), Exp.nPoints = 4096; end
if ~isfield(Exp,'Harmonic'), Exp.Harmonic = 1; end
if ~isfield(Exp,'Range'), Exp.Range = []; end
if ~isfield(Exp,'ModAmp'), Exp.ModAmp = 0; end
if isfield(Exp,'Temperature'), error('Exp.Temperature not supported.'); end

if ~((Exp.Harmonic==0) || (Exp.Harmonic==1) || (Exp.Harmonic==2))
  error('Exp.Harmonic must be 0, 1 or 2.');
end

if isempty(Exp.Range), error('Define the field range'); end
% 
%Isotopologues calculation
Is=isotopologues(Sys.Nucs);
nIso=Is.nIso;
if nIso==1
    [B,spc] = exchange(Sys,Exp,Opt); %only one isotopologue
else
    spc=zeros(1,Exp.nPoints);
    for i=1:nIso
        Sys1=Sys;
        Sys1.Nucs=Is.Nucs{i};
        A=Sys.A;
        Ascale=Is.Ascale{i};
        Ascale=repmat(Ascale,size(A,1),1);
        A=A.*Ascale;
        Sys1.A=A;
        [B,spc1]=exchange(Sys1,Exp,Opt);
        spc1=spc1*Is.Abund(i);
        spc=spc+spc1;
    end
end

% Output
%-------------------------------------------------------------
switch nargout
  case 0
    plot(B,spc);
    
    axis tight
    xlabel('magnetic field (mT)');
  case 1
    varargout = {spc};
  case 2
    varargout = {B,spc};
  otherwise
    error('Wrong number of output arguments.');
end

