function varargout = exchange2(Sys,Exp,Opt)

% Wrapper with arbitrary line broadening 
% 

if (nargin<2), Exp = struct; end
if (nargin<3), Opt = struct; end
if ~isstruct(Sys), error('Spin system structure Sys is missing.'); end
if ~isstruct(Exp), error('Experiment structure Exp is missing.'); end
% Experimental parameters
%------------------------------------------------------------
if ~isfield(Exp,'mwFreq'), Exp.mwFreq = 9.5; end
if ~isfield(Exp,'nPoints'), Exp.nPoints = 4096; end
if ~isfield(Exp,'Harmonic'), Exp.Harmonic = 1; end
if ~isfield(Exp,'Range'), Exp.Range = []; end
if ~isfield(Exp,'ModAmp'), Exp.ModAmp = 0; end
if isfield(Exp,'Temperature'), error('Exp.Temperature not supported.'); end

if ~((Exp.Harmonic==0) || (Exp.Harmonic==1) || (Exp.Harmonic==2))
  error('Exp.Harmonic must be 0, 1 or 2.');
end

if ~isfield(Sys,'lb'), error('Additional broadening is undefined'); end
Sys.lb=Sys.lb-min(Sys.lb); %set minimal broadening to zero

if isempty(Exp.Range), error('Define the field range'); end
isSeparate = isfield(Opt,'Output')&&strcmp(Opt.Output,'separate');
% 
%Force some options
Opt.Output = 'separate';
Opt.Method = 2;
Opt.reduce = 0;
[B,spc] = exchange(Sys,Exp,Opt); %calculate separate spectra
nLines = size(spc,1); %number of lines
if nLines~=numel(Sys.lb)
    error ('%d broadenings is expected for %d lines',nLines,nLines);
else
    if isSeparate
        spc1=spc;
    else
        spc1=zeros(1,Exp.nPoints);
        df=(max(Exp.Range)-min(Exp.Range))/Exp.nPoints; %field step for convspec
        for i=1:nLines
            spc1=spc1 + convspec(spc(i,:),df,Sys.lb(nLines-i+1),0,0);
        end
    end
end

% Output
%-------------------------------------------------------------
switch nargout
  case 0
    plot(B,spc1);
    
    axis tight
    xlabel('magnetic field (mT)');
  case 1
    varargout = {spc1};
  case 2
    varargout = {B,spc1};
  otherwise
    error('Wrong number of output arguments.');
end

